inline void OFoldStream::setMargins(size_t lm, size_t rm)
{
    OFoldBuf::setMargins(lm, rm);
}
